sqlobject.tests.test_postgres module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_postgres module

class `sqlobject.tests.test_postgres.` `SOTestSOList`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_so_list
  `q` = so_test_so_list
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_postgres.SOTestSOList`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_so_list'

class `sqlobject.tests.test_postgres.` `SOTestSOME`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_som_e
  `q` = so_test_som_e
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_postgres.SOTestSOME`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_som_e'
  property `value`

class `sqlobject.tests.test_postgres.` `SOTestSSLMode`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_ssl_mode
  `q` = so_test_ssl_mode
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_postgres.SOTestSSLMode`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_ssl_mode'
  property `test`

`sqlobject.tests.test_postgres.` `test_SOME`()

`sqlobject.tests.test_postgres.` `test_list_databases`()

`sqlobject.tests.test_postgres.` `test_list_tables`()

`sqlobject.tests.test_postgres.` `test_sslmode`()